import dataclasses


@dataclasses.dataclass
class AluminumCircular(object):
    """This is a dataclass containing the properties of an Aluminum Circular section.

    :param A: Cross-sectional area (in^2)
    :type A: float
    :param I: Moment of inertia (in^4)
    :type I: float
    :param ID: Inner diameter (in)
    :type ID: float
    :param J: Torsional constant (in^4)
    :type J: float
    :param OD: Outer diameter (in)
    :type OD: float
    :param Rb_t: Ratio of bend radius to thickness = (OD + ID) / (4 * t)
    :type Rb_t: float
    :param S: Elastic section modulus (in^3)
    :type S: float
    :param Size: The section size name
    :type Size: str
    :param W: Nominal weight (lb/ft)
    :type W: float
    :param Z: Plastic section modulus (in^3)
    :type Z: float
    """

    A: float
    I: float
    ID: float
    J: float
    OD: float
    Rb_t: float
    S: float
    Size: str
    W: float
    Z: float
    r: float
    t: float


ALL_ALUMINUM_CIRCULAR_NAMES = (
    "HSS 1.5 x 0.062",
    "HSS 1.5 x 0.094",
    "HSS 1.5 x 0.156",
    "HSS 1.5 x 0.125",
    "HSS 1.5 x 0.188",
    "HSS 1.5 x 0.25",
    "HSS 1.625 x 0.125",
    "HSS 1.625 x 0.188",
    "HSS 1.625 x 0.25",
    "HSS 1.75 x 0.125",
    "HSS 1.75 x 0.25",
    "HSS 1.5 x 0.375",
    "HSS 1.75 x 0.375",
    "HSS 1.875 x 0.125",
    "HSS 1.75 x 0.188",
    "HSS 1.875 x 0.188",
    "HSS 1.875 x 0.25",
    "HSS 1.875 x 0.375",
    "HSS 2.25 x 0.5",
    "HSS 2.375 x 0.188",
    "HSS 2.375 x 0.25",
    "HSS 2.375 x 0.375",
    "HSS 2.375 x 0.5",
    "HSS 2.5 x 0.125",
    "HSS 2.5 x 0.188",
    "HSS 2.5 x 0.25",
    "HSS 2.5 x 0.312",
    "HSS 2.5 x 0.375",
    "HSS 2 x 0.5",
    "HSS 2.5 x 0.5",
    "HSS 2.5 x 0.75",
    "HSS 2.5 x 0.625",
    "HSS 2.625 x 0.25",
    "HSS 2 x 0.125",
    "HSS 2 x 0.188",
    "HSS 2 x 0.375",
    "HSS 2 x 0.25",
    "HSS 2 x 0.312",
    "HSS 2.25 x 0.312",
    "HSS 2.75 x 0.188",
    "HSS 2.25 x 0.125",
    "HSS 2.75 x 0.125",
    "HSS 2.25 x 0.25",
    "HSS 2.75 x 0.25",
    "HSS 2.75 x 0.375",
    "HSS 2.25 x 0.375",
    "HSS 2.75 x 0.625",
    "HSS 2.75 x 0.5",
    "HSS 2.875 x 0.25",
    "HSS 2.75 x 0.75",
    "HSS 2.75 x 0.312",
    "HSS 2.875 x 0.5",
    "HSS 3 x 0.125",
    "HSS 3 x 0.188",
    "HSS 3 x 0.25",
    "HSS 2.25 x 0.188",
    "HSS 3 x 0.375",
    "HSS 3 x 0.5",
    "HSS 3 x 0.625",
    "HSS 3 x 0.75",
    "HSS 3 x 1",
    "HSS 3.25 x 0.25",
    "HSS 3.25 x 0.5",
    "HSS 3.25 x 0.375",
    "HSS 3.5 x 0.125",
    "HSS 3.5 x 0.188",
    "HSS 3.5 x 0.312",
    "HSS 3.5 x 0.25",
    "HSS 3.5 x 0.5",
    "HSS 3.5 x 0.375",
    "HSS 3.75 x 0.5",
    "HSS 4 x 0.125",
    "HSS 3.75 x 0.375",
    "HSS 3.75 x 0.188",
    "HSS 3.75 x 0.25",
    "HSS 3.75 x 0.125",
    "HSS 4 x 0.312",
    "HSS 4 x 0.625",
    "HSS 4 x 0.188",
    "HSS 4 x 0.25",
    "HSS 4 x 0.5",
    "HSS 4 x 0.75",
    "HSS 4 x 0.375",
    "HSS 4.25 x 0.125",
    "HSS 4.25 x 0.25",
    "HSS 4.25 x 0.375",
    "HSS 4.25 x 0.5",
    "HSS 4.5 x 0.125",
    "HSS 4.5 x 0.25",
    "HSS 4.5 x 0.188",
    "HSS 4.5 x 0.312",
    "HSS 4.5 x 0.375",
    "HSS 4.5 x 0.5",
    "HSS 4.5 x 0.625",
    "HSS 4.5 x 0.75",
    "HSS 4.5 x 1",
    "HSS 4.75 x 0.125",
    "HSS 4.75 x 0.188",
    "HSS 4.75 x 0.25",
    "HSS 4.75 x 0.375",
    "HSS 3.5 x 0.75",
    "HSS 4.75 x 0.5",
    "HSS 5 x 0.188",
    "HSS 5 x 0.25",
    "HSS 5 x 0.125",
    "HSS 5 x 0.312",
    "HSS 5 x 0.375",
    "HSS 5 x 0.5",
    "HSS 6 x 0.188",
    "HSS 6 x 0.25",
    "HSS 6 x 0.312",
    "HSS 6 x 0.375",
    "HSS 6 x 0.5",
    "HSS 6 x 0.625",
    "HSS 5.5 x 0.25",
    "HSS 6 x 0.75",
    "HSS 6.5 x 0.25",
    "HSS 6 x 1",
    "HSS 5 x 1",
    "HSS 6.5 x 0.375",
    "HSS 6.5 x 0.5",
    "HSS 6.75 x 0.5",
    "HSS 6.75 x 0.75",
    "HSS 5.5 x 0.125",
    "HSS 6.5 x 0.75",
    "HSS 5.5 x 0.188",
    "HSS 5 x 0.625",
    "HSS 5 x 0.75",
    "HSS 5.5 x 0.75",
    "HSS 5.5 x 1",
    "HSS 5.5 x 0.375",
    "HSS 6 x 0.125",
    "HSS 7 x 0.375",
    "HSS 5.5 x 0.5",
    "HSS 7 x 0.25",
    "HSS 7 x 1",
    "HSS 7.5 x 0.25",
    "HSS 7 x 0.5",
    "HSS 7.5 x 0.5",
    "HSS 8 x 0.25",
    "HSS 8 x 0.125",
    "HSS 7.5 x 0.375",
    "HSS 8 x 0.375",
    "HSS 8 x 0.625",
    "HSS 8 x 0.5",
    "HSS 8 x 0.75",
    "HSS 8 x 1",
    "HSS 7 x 0.75",
    "HSS 8.5 x 0.25",
    "HSS 9 x 0.25",
    "HSS 9 x 0.5",
    "HSS 10 x 0.25",
    "HSS 10 x 0.375",
    "HSS 10 x 0.5",
    "HSS 10 x 0.625",
    "HSS 10 x 0.75",
    "HSS 10.5 x 0.25",
    "HSS 10 x 1",
    "HSS 10.5 x 0.375",
    "HSS 10.5 x 0.5",
    "HSS 10.5 x 0.75",
    "HSS 11 x 0.5",
    "HSS 11 x 0.375",
    "HSS 11 x 0.75",
    "HSS 9 x 0.375",
    "HSS 11 x 1",
    "HSS 12 x 0.25",
    "HSS 12 x 0.375",
    "HSS 12 x 0.5",
    "HSS 12 x 0.75",
    "HSS 12 x 1",
    "PIPE 1/8 Sched 40",
    "PIPE 1/8 Sched 80",
    "PIPE 1/4 Sched 40",
    "PIPE 1/4 Sched 80",
    "PIPE 3/8 Sched 80",
    "PIPE 1/2 Sched 5",
    "PIPE 3/8 Sched 40",
    "PIPE 1/2 Sched 10",
    "PIPE 1/2 Sched 40",
    "PIPE 1/2 Sched 80",
    "PIPE 1/2 Sched 160",
    "PIPE 3/4 Sched 5",
    "PIPE 3/4 Sched 10",
    "PIPE 3/4 Sched 40",
    "PIPE 3/4 Sched 80",
    "PIPE 3/4 Sched 160",
    "PIPE 1 Sched 5",
    "PIPE 1 Sched 40",
    "PIPE 1 Sched 10",
    "PIPE 1 Sched 80",
    "PIPE 1 Sched 160",
    "PIPE 1.25 Sched 5",
    "PIPE 1.25 Sched 10",
    "PIPE 1.25 Sched 40",
    "PIPE 1.25 Sched 80",
    "PIPE 1.25 Sched 160",
    "PIPE 1.5 Sched 5",
    "PIPE 1.5 Sched 10",
    "PIPE 1.5 Sched 40",
    "PIPE 1.5 Sched 80",
    "PIPE 1.5 Sched 160",
    "PIPE 2 Sched 5",
    "PIPE 2 Sched 40",
    "PIPE 2 Sched 80",
    "PIPE 2 Sched 160",
    "PIPE 2 Sched 10",
    "PIPE 2.5 Sched 5",
    "PIPE 2.5 Sched 10",
    "PIPE 2.5 Sched 40",
    "PIPE 2.5 Sched 160",
    "PIPE 2.5 Sched 80",
    "PIPE 3 Sched 5",
    "PIPE 3 Sched 10",
    "PIPE 3 Sched 40",
    "PIPE 3 Sched 80",
    "PIPE 3 Sched 160",
    "PIPE 3.5 Sched 10",
    "PIPE 3.5 Sched 5",
    "PIPE 3.5 Sched 40",
    "PIPE 3.5 Sched 80",
    "PIPE 4 Sched 5",
    "PIPE 4 Sched 80",
    "PIPE 4 Sched 40",
    "PIPE 4 Sched 10",
    "PIPE 4 Sched 160",
    "PIPE 4 Sched 120",
    "PIPE 5 Sched 5",
    "PIPE 5 Sched 10",
    "PIPE 5 Sched 120",
    "PIPE 5 Sched 40",
    "PIPE 5 Sched 160",
    "PIPE 6 Sched 5",
    "PIPE 5 Sched 80",
    "PIPE 6 Sched 10",
    "PIPE 6 Sched 80",
    "PIPE 6 Sched 120",
    "PIPE 6 Sched 40",
    "PIPE 6 Sched 160",
    "PIPE 8 Sched 5",
    "PIPE 8 Sched 10",
    "PIPE 8 Sched 20",
    "PIPE 8 Sched 30",
    "PIPE 8 Sched 40",
    "PIPE 8 Sched 60",
    "PIPE 8 Sched 80",
    "PIPE 8 Sched 120",
    "PIPE 8 Sched 160",
    "PIPE 10 Sched 5",
    "PIPE 10 Sched 10",
    "PIPE 8 Sched 140",
    "PIPE 10 Sched 20",
    "PIPE 10 Sched 30",
    "PIPE 8 Sched 100",
    "PIPE 10 Sched 60",
    "PIPE 10 Sched 40",
    "PIPE 10 Sched 80",
    "PIPE 10 Sched 100",
    "PIPE 12 Sched 5",
    "PIPE 12 Sched 10",
    "PIPE 12 Sched 20",
    "PIPE 12 Sched 30",
    "PIPE 12 Sched 40",
    "PIPE 12 Sched 60",
    "PIPE 12 Sched 80",
)
